@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '1.001';
+our $VERSION = '1.002';
 $VERSION = eval $VERSION;
 
 require WWW::Shorten::_dead;
@@ -13,11 +13,11 @@ require WWW::Shorten::_dead;
 
 =head1 NAME
 
-WWW::Shorten::Qwer - Perl interface to L<http://qwer.org/>
+WWW::Shorten::Qwer - (DEPRECATED) URL Shorten Service
 
 =head1 SYNOPSIS
 
-  # no viable synopsis
+  # no viable use case
 
 =head1 DESCRIPTION
 
@@ -32,7 +32,9 @@ Dave Cross C<dave@perlhacks.com>
 
 =over
 
-=item Chase Whitener C<capoeirab@cpan.org> -- Current maintainer
+=item *
+
+Chase Whitener C<capoeirab@cpan.org>
 
 =back
 
